@@ -34,7 +34,7 @@ class Config(object):
                      "flag_help2": "help",
 
                      "error_prefix": "CM error:",
-                     "info_cli": "cm {action} {automation} {artifact(s)} {flags} @input.yaml @input.json",
+                     "info_cli": "cm {action} {automation} {artifact(s)} {--flags} @input.yaml @input.json",
 
                      "default_home_dir": "CM",
 
